package jp.flashcast.translator.android;

import jp.flashcast.translator.android.model.LanguageModel;
import jp.flashcast.translator.android.model.TranslateModel;
import jp.flashcast.translator.android.thread.TranslateThread;
import android.app.Activity;
import android.app.ProgressDialog;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.Toast;
import android.widget.ToggleButton;

public class TranslatorSample2 extends Activity implements Runnable {
    private ProgressDialog dialog;
    private TranslateModel model;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        initSpinners();
        initButtons();
    }
    
    private void initSpinners() {
    	Spinner spSrc = (Spinner)findViewById(R.id.srclanguage);
    	Spinner spDst = (Spinner)findViewById(R.id.dstlanguage);
    	
    	String[] labels = getResources().getStringArray(R.array.language_label);
    	String[] values = getResources().getStringArray(R.array.language_value);
    	ArrayAdapter<LanguageModel> adapter = new ArrayAdapter<LanguageModel>(this, android.R.layout.simple_spinner_item);
    	adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
    	
    	for (int i = 0; i < labels.length; i++) {
    		adapter.add(new LanguageModel(labels[i], values[i]));
    	}
    	
    	spSrc.setAdapter(adapter);
    	spDst.setAdapter(adapter);
    }
    
    private void initButtons() {
        // 翻訳方向ボタン
        ToggleButton btnVector = (ToggleButton)findViewById(R.id.vector);
        btnVector.setTextOff(">>");
        btnVector.setTextOn("<<");
        btnVector.setBackgroundResource(android.R.drawable.btn_default);
        
        // Tweetボタン
        Button btnTweet = (Button)findViewById(R.id.tweet);
        btnTweet.setOnClickListener(new OnClickListener() {

			public void onClick(View v) {
				// TODO Auto-generated method stub
				
			}
        	
        });
        
        // 翻訳ボタン
        Button btnTranslate = (Button)findViewById(R.id.translate);
        btnTranslate.setOnClickListener(new OnClickListener() {

			public void onClick(View v) {
    			EditText text;
    			Spinner spSrc;
    			Spinner spDst;
    			
    			ToggleButton btnVector = (ToggleButton)findViewById(R.id.vector);
    			
    			if (btnVector.isChecked()) {
    				text = (EditText)findViewById(R.id.dsttext);
    				spSrc = (Spinner)findViewById(R.id.dstlanguage);
    				spDst = (Spinner)findViewById(R.id.srclanguage);
    			}
    			else {
    				text = (EditText)findViewById(R.id.srctext);
    				spSrc = (Spinner)findViewById(R.id.srclanguage);
    				spDst = (Spinner)findViewById(R.id.dstlanguage);
    			}
    			
    			if (!text.getText().toString().equals("")) {
    				if (model == null) {
    					model = new TranslateModel();
    				}
    				
    				model.setOriginal(text.getText().toString());
    				model.setSrcLanguage(((LanguageModel)spSrc.getSelectedItem()).getValue());
    				model.setDstLanguage(((LanguageModel)spDst.getSelectedItem()).getValue());
    				
    				Translate();
    			}
			}
        	
        });
    }
    
    private void Translate() {
    	if (dialog == null) {
    		dialog = new ProgressDialog(TranslatorSample2.this);
    		dialog.setIndeterminate(true);
    	}
		dialog.setMessage("Translating... Please wait.");
    	dialog.show();

    	(new TranslateThread(new Handler(), TranslatorSample2.this, model)).start();
    }

	public void run() {
		dialog.dismiss();
		
		if (model.isSuccess()) {
			((EditText)findViewById(
				(!((ToggleButton)findViewById(R.id.vector)).isChecked()) ? R.id.dsttext : R.id.srctext))
				.setText(model.getTranslated()); 
		}
		else {
			Toast.makeText(this, "Failed to translate...", Toast.LENGTH_SHORT).show();
		}
	}
}