package jp.flashcast.translator.android.thread;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Date;

import jp.flashcast.translator.android.model.TranslateModel;

import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.NameValuePair;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.json.JSONException;
import org.json.JSONObject;

import android.os.Handler;

public class TranslateThread extends Thread {
	private Handler handler;
	private Runnable runnable;
	private final HttpClient client;
	private final HttpPost post;
	private final static String G_TRANSLATE_API_URL = "http://ajax.googleapis.com/ajax/services/language/translate";
	private final static String G_TRANSLATE_API_VERSION = "1.0";
	private TranslateModel model;
	
	public TranslateThread(Handler handler, Runnable runnable, TranslateModel model) {
		this.handler = handler;
		this.runnable = runnable;
		this.model = model;
		this.client = new DefaultHttpClient();
		this.post = new HttpPost(G_TRANSLATE_API_URL);
	}
	
	private String Translate(String query, String srcLanguage, String dstLanguage) {
		ArrayList<NameValuePair> params = new ArrayList<NameValuePair>(4);
		params.add(new BasicNameValuePair("v", G_TRANSLATE_API_VERSION));
		params.add(new BasicNameValuePair("q", query));
		params.add(new BasicNameValuePair("format", "text"));
		params.add(new BasicNameValuePair("langpair", srcLanguage + "|" + dstLanguage));
		
		StringBuilder builder = new StringBuilder();
		
		try {
			post.setEntity(new UrlEncodedFormEntity(params, "UTF-8"));
			final HttpResponse response = client.execute(post);
			
			if (response.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
				InputStream stream = response.getEntity().getContent();
				BufferedReader reader = new BufferedReader(new InputStreamReader(stream));
				
				String line;
				
				while ((line = reader.readLine()) != null) {
					builder.append(line);
				}
				stream.close();
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		return builder.toString();
	}
	
	@Override
	public void run() {
		if (model != null) {
			String translated = Translate(model.getOriginal(), model.getSrcLanguage(), model.getDstLanguage());
			
			try {
				JSONObject json = new JSONObject(translated);
				
				if (json.has("responseStatus") && json.getInt("responseStatus") == 200) {
					model.setTranslated(json.getJSONObject("responseData").getString("translatedText"));
					model.setDt(new Date().toLocaleString());
					model.setSuccess(true);
				}
				else {
					model.setSuccess(false);
				}
			} catch (JSONException e) {
				model.setSuccess(false);
			}
			
			handler.post(runnable);
		}
	}
}
